@@ -5,14 +5,14 @@
 
 """circuits
 
-Lightweight Event driven Framework
+Lightweight Event driven and Asynchronous Application Framework
 
 :copyright: CopyRight (C) 2004-2011 by James Mills
 :license: MIT (See: LICENSE)
 """
 
 __author__ = "James Mills"
-__date__ = "5th February 2011"
-__version__ = "1.3.3"
+__date__ = "12th February 2011"
+__version__ = "1.4"
 
 from core import *
