@@ -9,8 +9,6 @@ This module definse the Manager class subclasses by component.BaseComponent
 
 import os
 from time import sleep
-from warnings import warn
-from itertools import chain
 from types import TupleType
 from threading import Thread
 from collections import deque
@@ -44,6 +42,16 @@ except:
     except:
         HAS_MULTIPROCESSING = 0
 
+
+#
+# Compatibility and consistency fixes
+#
+
+if HAS_MULTIPROCESSING == 2:
+    setattr(Process, "isAlive", Process.is_alive)
+elif HAS_MULTIPROCESSING == 1:
+    setattr(Process, "pid", property(Process.getPid))
+
 from values import Value
 from events import Started, Stopped, Signal
 from events import Error, Success, Failure, Filter, Start, End
@@ -70,6 +78,7 @@ class Manager(object):
         self.channels = dict()
         self._handlers = set()
         self._handlerattrs = dict()
+        self._handler_cache = dict()
 
         self._ticks = set()
 
@@ -94,10 +103,8 @@ class Manager(object):
         h = len(self._handlers)
         state = self.state
 
-        if HAS_MULTIPROCESSING == 2:
-            pid = current_process().ident
-        if HAS_MULTIPROCESSING == 1:
-            pid = current_process().getPid()
+        if HAS_MULTIPROCESSING:
+            pid = current_process().pid
         else:
             pid = os.getpid()
 
@@ -181,10 +188,11 @@ class Manager(object):
         return self
 
     def _getHandlers(self, _channel):
+        if _channel in self._handler_cache:
+            return self._handler_cache[_channel]
+
         target, channel = _channel
 
-        channels = self.channels
-        exists = self.channels.has_key
         get = self.channels.get
         tmap = self._tmap.get
         cmap = self._cmap.get
@@ -200,27 +208,27 @@ class Manager(object):
         if channel == "*":
             handlers.extend(tmap(target, []))
             handlers.sort(key=_sortkey, reverse=True)
+            self._handler_cache[_channel] = handlers
             return handlers
 
         # Every channel on this target
         if target == "*":
             handlers.extend(cmap(channel, []))
             handlers.sort(key=_sortkey, reverse=True)
+            self._handler_cache[_channel] = handlers
             return handlers
 
         # Any global channels
-        if exists(("*", channel)):
-            handlers.extend(get(("*", channel)))
+        handlers.extend(get(("*", channel), []))
  
         # Any global channels for this target
-        if exists((channel, "*")):
-            handlers.extend(get((channel, "*")))
+        handlers.extend(get((channel, "*"), []))
 
         # The actual channel and target
-        if exists(_channel):
-            handlers.extend(get((_channel)))
+        handlers.extend(get(_channel, []))
 
         handlers.sort(key=_sortkey, reverse=True)
+        self._handler_cache[_channel] = handlers
         return handlers
 
     @property
@@ -258,6 +266,8 @@ class Manager(object):
         Add a new Event Handler to the Event Manager.
         """
 
+        self._handler_cache.clear()
+
         channels = getattr(handler, "channels", channels)
 
         target = kwargs.get("target", getattr(handler, "target",
@@ -326,6 +336,8 @@ class Manager(object):
         if the specified  handler has already been removed.
         """
 
+        self._handler_cache.clear()
+
         if channel is None:
             if handler in self._globals:
                 self._globals.remove(handler)
@@ -414,7 +426,8 @@ class Manager(object):
     def _flush(self):
         q = self._queue
         self._queue = deque()
-        while q: self.__handleEvent(*q.popleft())
+        for event, channel in q:
+            self.__handleEvent(event, channel)
 
     def flushEvents(self):
         """Flush all Events in the Event Queue
@@ -473,17 +486,12 @@ class Manager(object):
         if signal in [SIGINT, SIGTERM]:
             self.stop()
 
-    def start(self, sleep=None, log=True, link=None, process=False):
-        if sleep:
-            warn(DeprecationWarning(
-                "sleep will be deprecated in a future release. " +
-                "Set circuits.core.TIMEOUT instead."))
-
+    def start(self, log=True, link=None, process=False):
         group = None
         target = self.run
         name = self.__class__.__name__
         mode = "P" if process else "T"
-        args = (sleep, log, mode,)
+        args = (log, mode,)
 
         if process and HAS_MULTIPROCESSING:
             if link is not None and isinstance(link, Manager):
@@ -498,8 +506,6 @@ class Manager(object):
 
             self._task = Process(group, target, name, args)
             self._task.daemon = True
-            if HAS_MULTIPROCESSING == 2:
-                setattr(self._task, "isAlive", self._task.is_alive)
             self.tick()
             self._task.start()
             return
@@ -533,17 +539,15 @@ class Manager(object):
         else:
             sleep(TIMEOUT) # Nothing to do - Let's not tie up the CUP
 
-    def run(self, sleep=None, log=True, __mode=None, __socket=None):
-        if sleep:
-            warn(DeprecationWarning(
-                "sleep will be deprecated in a future release. " +
-                "Set circuits.core.TIMEOUT instead."))
-
-        if not __mode == "T" and current_thread().getName() == "MainThread":
+    def run(self, log=True, __mode=None, __socket=None):
+        if current_thread().getName() == "MainThread":
             if os.name == "posix":
                 _registerSignalHandler(SIGHUP, self._signalHandler)
-            _registerSignalHandler(SIGINT, self._signalHandler)
-            _registerSignalHandler(SIGTERM, self._signalHandler)
+            try:
+                _registerSignalHandler(SIGINT, self._signalHandler)
+                _registerSignalHandler(SIGTERM, self._signalHandler)
+            except ValueError:
+                pass # Ignore if we can't install signal handlers
 
         if __socket is not None:
             from circuits.core.bridge import Bridge
