@@ -9,7 +9,10 @@ from time import time
 def wait_for(obj, attr, value=True, timeout=30.0):
     etime = time() + timeout
     while time() < etime:
-        if getattr(obj, attr) == value:
+        if callable(value):
+            if value(obj, attr):
+                return True
+        elif getattr(obj, attr) == value:
             return True
     return False
 
