@@ -4,8 +4,8 @@ import os
 
 import pytest
 
-from circuits.core import workers
-if not workers.HAS_MULTIPROCESSING:
+from circuits.core.manager import HAS_MULTIPROCESSING
+if not HAS_MULTIPROCESSING:
     pytest.skip("Skip: No multiprocessing support")
 
 from circuits.net.sockets import Pipe
@@ -49,3 +49,5 @@ def test():
     assert x[0] == "Hello from %s" % pid
     assert x[1].startswith("Hello from")
     assert not x[0]  == x[1]
+
+    p.stop()
