@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 
-from time import sleep
+import pytest
 
-import py
-py.test.skip("XXX: Not passing...")
+from circuits.core.manager import HAS_MULTIPROCESSING
+if not HAS_MULTIPROCESSING:
+    pytest.skip("Skip: No multiprocessing support")
 
-from circuits import Event, Component, Manager
+from circuits import handler, Event, Component, Manager
 
 class Hello(Event):
     """Hello Event"""
@@ -23,7 +24,10 @@ def test():
     app.start(link=m, process=True)
 
     x = m.push(Hello())
-    sleep(1)
 
+    assert pytest.wait_for(x, "result")
     s = str(x)
     assert s == "Hello World!"
+
+    m.stop()
+    app.stop()
