@@ -8,9 +8,13 @@ class Client(Component):
         super(Client, self).__init__()
 
         self.data = ""
+        self.ready = True
         self.connected = False
         self.disconnected = False
 
+    def ready(self, component):
+        self.ready = True
+
     def connected(self, host, port):
         self.connected = True
 
