@@ -9,9 +9,13 @@ class Server(Component):
         super(Server, self).__init__()
 
         self.data = ""
+        self.ready = False
         self.connected = False
         self.disconnected = False
 
+    def ready(self, component):
+        self.ready = True
+
     def connect(self, sock, *args):
         self.connected = True
         self.push(Write(sock, "Ready"))
