@@ -5,8 +5,8 @@ from urllib2 import urlopen
 
 import pytest
 
-from circuits.core import workers
-if not workers.HAS_MULTIPROCESSING:
+from circuits.core.manager import HAS_MULTIPROCESSING
+if not HAS_MULTIPROCESSING:
     pytest.skip("Skip: No multiprocessing support")
 
 from circuits.web import Controller
@@ -31,3 +31,4 @@ def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
     assert s == "Hello %d i'm %d" % (os.getpid(), t._task.pid)
+    t.stop()
